@@ -1,8 +1,12 @@
 first_dimensions_match = function(e1, e2) {
 	d1 = st_dimensions(e1)
 	d2 = st_dimensions(e2)
+	crs1 = st_crs(d1)
+	crs2 = st_crs(d2)
+	st_crs(d1) = st_crs(NA)
+	st_crs(d2) = st_crs(NA)
 	n = min(length(d1), length(d2))
-	isTRUE(all.equal(d1[1:n], d2[1:n], check.attributes = FALSE))
+	isTRUE(all.equal(d1[1:n], d2[1:n], check.attributes = FALSE)) && crs1 == crs2
 }
 
 #' S3 Ops Group Generic Functions for stars objects
@@ -29,8 +33,12 @@ first_dimensions_match = function(e1, e2) {
 #' needs to make sure this is sensible; it may be needed to use \code{aperm}
 #' to permutate dimensions first. 
 Ops.stars <- function(e1, e2) {
-	if (!missing(e2) && inherits(e1, "stars") && inherits(e2, "stars") && !first_dimensions_match(e1, e2))
-		stop("(first) dimensions of e1 and e2 do not match")
+	if (!missing(e2)) { 
+		if (inherits(e1, "stars") && inherits(e2, "stars") && !first_dimensions_match(e1, e2))
+			stop("(first) dimensions of e1 and e2 do not match")
+		if (!inherits(e2, "stars"))
+			e1 = drop_units(e1)
+	}
 	ret = if (missing(e2))
 			lapply(e1, .Generic)
 		else if (!inherits(e2, "stars"))
@@ -47,7 +55,7 @@ Ops.stars <- function(e1, e2) {
 	if (any(sapply(ret, function(x) is.null(dim(x))))) # happens if e1[[1]] is a factor; #304
 		ret = lapply(ret, function(x) { dim(x) = dim(e1); x })
 	if (! inherits(e1, "stars"))
-		setNames(st_as_stars(ret, dimensions = st_dimensions(e2)), names(e2))
+		st_as_stars(setNames(ret, names(e2)), dimensions = st_dimensions(e2))
 	else
 		st_as_stars(ret, dimensions = st_dimensions(e1))
 }
